// $Id: Concatenate.java 10479 2009-07-10 09:51:07Z chris $

import org.faceless.pdf2.*;
import java.io.*;
import java.util.*;

/**
 * One of the most common requests we get is "How do I join two
 * documents together". This example shows just that, in the simplest
 * correct way possible.
 *
 * The "getPages()" method here is only being used to add pages to the
 * end, but as it returns a java.util.List it's easy to manipulate the
 * list as necessary. The same applies to Bookmarks and Fields.
 */
public class Concatenate
{
    public static void main(String[] args) throws IOException {
        if (args.length<2) {
            System.out.println("Usage: java Concatenate <file1> <file2> ... <filen>");
            System.out.println("       Creates file \"Concatenate.pdf\"");
            System.exit(0);
        }

        PDF pdf = new PDF(new PDFReader(new File(args[0])));
        if (pdf.getBasicOutputProfile().isSet(OutputProfile.Feature.XFAForm)) {
            System.out.println("WARNING: Can't merge XFA Forms - removing XFA components");
            pdf.getForm().removeXFA();
        }

        // Merge two PDF's by joining:
        // * The Pages list
        // * The Bookmarks list
        // * The Form Fields
        // * Named actions and Embedded files (less commonly used)

        Map elements = pdf.getForm().getElements();
        for (int i=1;i<args.length;i++) {
            PDF newpdf = new PDF(new PDFReader(new File(args[i])));
            pdf.getPages().addAll(newpdf.getPages());
            pdf.getNamedActions().putAll(newpdf.getNamedActions());
            pdf.getEmbeddedFiles().putAll(newpdf.getEmbeddedFiles());

            pdf.getBookmarks().addAll(newpdf.getBookmarks());
            Map newelements = newpdf.getForm().getElements();
            if (new HashSet(elements.keySet()).removeAll(newelements.keySet())) {
                throw new IllegalStateException("Forms contain duplicate field names");
            } else {
                elements.putAll(newelements);
            }
        }

        FileOutputStream out = new FileOutputStream("Concatenate.pdf");
        pdf.render(out);
        out.close();
    }
}
