// $Id: RotateClockwise.java 14034 2011-10-13 16:44:21Z mike $

package org.faceless.pdf2.viewer2.feature;

import org.faceless.pdf2.viewer2.*;
import org.faceless.pdf2.*;
import javax.swing.*;
import javax.swing.undo.*;
import javax.swing.event.*;
import java.awt.event.*;

/**
 * Create a button that will rotate the page 90 degrees clockwise.
 *
 * <span class="featurename">The name of this feature is <span class="featureactualname">RotateClockwise</span></span>
 * <p><i>This code is copyright the Big Faceless Organization. You're welcome to use, modify and distribute it in any form in your own projects, provided those projects continue to make use of the Big Faceless PDF library.</i></p>
 * @since 2.8.3
 */
public class RotateClockwise extends ViewerWidget implements DocumentPanelListener {

    protected RotateClockwise(String name) {
        super(name);
        setButton("Edit", "resources/icons/"+name+".png", "PDFViewer.tt."+name);
        setMenu("View\t"+name);
    }

    public RotateClockwise() {
        this("RotateClockwise");
    }

    public void initialize(PDFViewer viewer) {
        super.initialize(viewer);
        viewer.addDocumentPanelListener(this);
        getComponent().setEnabled(false);
    }

    public void documentUpdated(DocumentPanelEvent event) {
        if (event.getType() == "activated" || event.getType() == "redrawn") {
            PDF pdf = event.getDocumentPanel().getPDF();
            EncryptionHandler handler = pdf==null ? null : pdf.getEncryptionHandler();
            getComponent().setEnabled(handler == null || handler.hasRight("Assemble"));
        } else if (event.getType() == "deactivated") {
            getComponent().setEnabled(false);
        }
    }

    public void action(ViewerEvent event) {
        rotate(event, 90);
    }

    protected void rotate(ViewerEvent event, final int diff) {

        final DocumentPanel docpanel = event.getDocumentPanel();
        final PDFPage page = event.getDocumentPanel().getPage();
        page.setPageOrientation(page.getPageOrientation() + diff);

        docpanel.fireUndoableEditEvent(new UndoableEditEvent(docpanel, new AbstractUndoableEdit() {
            public String getPresentationName() {
                return UIManager.getString("PDFViewer.RotateClockwise");
            }
            public void undo() {
                super.undo();
                undoredo(-diff);
            }
            public void redo() {
                super.redo();
                undoredo(diff);
            }
            private void undoredo(int diff) {
                page.setPageOrientation(page.getPageOrientation() + diff);
            }
        }));
    }

    public boolean isButtonEnabledByDefault() {
        return false;
    }

}
